from django.shortcuts import render, redirect, get_object_or_404
from django.urls import reverse
from django.views import View

from web.models import Article, StatusChoices


def index_view(request):
    return render(
        request, 'index.html', context={
            'articles': Article.objects.order_by('title'),
            'reverse': reverse('articles-detail', kwargs={'id': 1})
        }
    )


# Class-based views
class ArticleCreateView(View):
    def get(self, request, *args, **kwargs):
        return render(
            self.request,
            'article_create.html',
            context={
                'status_choices': StatusChoices.choices
            }
        )

    def post(self, request, *args, **kwargs):
        data = request.POST
        article_data = {
            'title': data.get('title'),
            'text': data.get('text'),
            'author': data.get('author'),
            'status': data.get('status')
        }

        article = Article.objects.create(**article_data)

        return redirect('articles-detail', id=article.id)


# def article_create_view(request):
#     if request.method == 'GET':
#         return render(
#             request,
#             'article_create.html',
#             context={
#                 'status_choices': StatusChoices.choices
#             }
#         )
#
#     elif request.method == 'POST':
#         data = request.POST
#         article_data = {
#             'title': data.get('title'),
#             'text': data.get('text'),
#             'author': data.get('author'),
#             'status': data.get('status')
#         }
#
#         article = Article.objects.create(**article_data)
#
#         return redirect('articles-detail', id=article.id)


# /articles/{id}
def article_detail_view(request, id: int):
    article = get_object_or_404(Article, id=id)
    return render(request, 'article.html', context={'article': article})
